@@ -45,7 +45,7 @@ char wminet_mask_bits[64*64];
 int  wminet_mask_width = 64;
 int  wminet_mask_height = 64;
 
-#define WMPOP3_VERSION "0.7"
+#define WMPOP3_VERSION "0.8"
 
 #define CHAR_WIDTH   5
 #define CHAR_HEIGHT  7
@@ -53,6 +53,7 @@ int  wminet_mask_height = 64;
 #define YES          1
 #define NO           0
 #define STR_LENGTH  32
+#define MAX_RUN_COMMAND_STR_LENGTH      255
 
 char *ProgName;
 
@@ -60,7 +61,7 @@ typedef struct {
   char password[STR_LENGTH];
   char username[STR_LENGTH];
   char popserver[4*STR_LENGTH];
-  char mailserverid[2];
+  char mailserverid[4];
   int  port;
   int  nMsgs;
   int  nUnread;
@@ -71,6 +72,7 @@ typedef struct {
   char mailclient[STR_LENGTH];
   char middle_click_cmd[STR_LENGTH];
   char right_click_cmd[STR_LENGTH];
+  char run_command[MAX_RUN_COMMAND_STR_LENGTH];
   int  autoChecking;
   int  mailCheckDelay;
   int  viewUnread;
@@ -138,7 +140,7 @@ int main(int argc, char *argv[]) {
       case 'c' :
 	if (argc > (i+1))
 	  {
-	    strcpy(config_file, argv[i+1]);
+	    strncpy(config_file, argv[i+1], sizeof(config_file));
 	    i++;
 	  }
 	break;
@@ -178,7 +180,7 @@ void wmCheckMail_routine(int argc, char **argv){
   
   /* Find config-file */
   if( !strcmp( config_file, "not-defined") ) {
-    sprintf(config_file, "%s/.wmmultipop3rc", getenv("HOME")); 
+    snprintf(config_file, sizeof(config_file), "%s/.wmmultipop3rc", getenv("HOME")); 
   }
 
   /* Read config */
@@ -299,6 +301,7 @@ void wmCheckMail_routine(int argc, char **argv){
 
       if( nTotMail > 0) {
         copyXPMArea(72, 2, 45, 28, 4, 4 ); 
+	system(conf.run_command);
       } else {
 	copyXPMArea(72, 33, 45, 28, 4, 4 );  
       } 
@@ -451,7 +454,7 @@ int  readConfigFile(char *filename) {
 
   /* If we don't have a configfile, output a new one */
   if ( (fp = fopen( filename, "r" )) == 0) {
-    sprintf(config_file, "%s/.wmmultipop3rc", getenv("HOME"));
+    snprintf(config_file, sizeof(config_file), "%s/.wmmultipop3rc", getenv("HOME"));
     printf("-Config file does not exit : %s\n",config_file);
     printf("+Trying to create new config file.\n");
     if((fp = fopen(config_file,"w")) == 0){
@@ -464,7 +467,8 @@ int  readConfigFile(char *filename) {
     fprintf(fp, "mailcheckdelay    10     # default mail check time in minutes\n");
     fprintf(fp, "mailclient        balsa  # this is the command you want to run on leftclick\n");
     fprintf(fp, "middle_click_cmd  balsa\n");
-    fprintf(fp, "right_click_cmd   wmmultipop3cfg\n\n");
+    fprintf(fp, "right_click_cmd   wmmultipop3cfg\n");
+    fprintf(fp, "run_command       /bin/false\n\n");
     fprintf(fp, "[Mailserver 1]\n");
     fprintf(fp, "popserver         < pop3 server name >\n");
     fprintf(fp, "port              110    # default port\n");
@@ -524,7 +528,7 @@ int  readConfigFile(char *filename) {
 	  printf("Error in mailclient string\n");
 	  return -1;
 	}
-	strcpy(conf.mailclient, ptr);
+	strncpy(conf.mailclient, ptr, sizeof(conf.mailclient));
       }
       if ( !strcmp(ptr, "middle_click_cmd") ) {
 	ptr = strtok( 0, "\n");
@@ -532,7 +536,7 @@ int  readConfigFile(char *filename) {
 	  printf("Error in middle_click_cmd string\n");
 	  return -1;
 	}
-	strcpy(conf.middle_click_cmd, ptr);
+	strncpy(conf.middle_click_cmd, ptr, sizeof(conf.middle_click_cmd));
       }
       if ( !strcmp(ptr, "right_click_cmd") ) {
 	ptr = strtok( 0, "\n");
@@ -540,7 +544,15 @@ int  readConfigFile(char *filename) {
 	  printf("Error in right_click_cmd string\n");
 	  return -1;
 	}
-	strcpy(conf.right_click_cmd, ptr);
+	strncpy(conf.right_click_cmd, ptr, sizeof(conf.right_click_cmd));
+      }
+      if ( !strcmp(ptr, "run_command") ) {
+	ptr = strtok( 0, "\n");
+	if ( ptr == 0 ) {
+	  printf("Error in run_command string\n");
+	  return -1;
+	}
+	strncpy(conf.run_command, ptr, sizeof(conf.run_command));
       }
 
       if ( !strcmp(ptr, "popserver") ) {
@@ -553,7 +565,7 @@ int  readConfigFile(char *filename) {
 	if (popservers > 0)
 	  conf.c = (MailServerConf **)realloc(conf.c,(popservers+1)*sizeof(MailServerConf));
 	conf.c[popservers]=(MailServerConf *)malloc(sizeof(MailServerConf));
-	strcpy(conf.c[popservers]->popserver, ptr);
+	strncpy(conf.c[popservers]->popserver, ptr, sizeof(conf.c[popservers]->popserver));
 	/*	conf.c[popservers]->nMailWaiting=0;*/
 	popservers++;
       }
@@ -572,7 +584,7 @@ int  readConfigFile(char *filename) {
 	  printf("Error in username string\n");
 	  return -1;
 	}
-	strcpy(conf.c[usernames]->username, ptr);
+	strncpy(conf.c[usernames]->username, ptr, sizeof(conf.c[usernames]->username));
 	usernames++;
       }
       if ( !strcmp(ptr, "password") ) {
@@ -581,7 +593,7 @@ int  readConfigFile(char *filename) {
 	  printf("Error in password string\n");
 	  return -1;
 	}
-	strcpy(conf.c[passwords]->password, ptr);
+	strncpy(conf.c[passwords]->password, ptr, sizeof(conf.c[passwords]->password));
 	passwords++;
       }
       if ( !strcmp(ptr, "mailserverid") ) {
@@ -590,7 +602,7 @@ int  readConfigFile(char *filename) {
 	  printf("Error in mail-server ID string\n");
 	  return -1;
 	}
-	strcpy(conf.c[ids]->mailserverid, ptr);
+	strncpy(conf.c[ids]->mailserverid, ptr, sizeof(conf.c[ids]->mailserverid));
 	ids++;
       }
     }
@@ -600,10 +612,10 @@ int  readConfigFile(char *filename) {
      to mailclient (eg. left mouse click). This will preserve compability with 
      configfiles belonging to older versions of wmmultipop3 */
   if ( strlen( conf.middle_click_cmd ) < 1 ) {
-    strcpy( conf.middle_click_cmd, conf.mailclient );
+    strncpy(conf.middle_click_cmd, conf.mailclient, sizeof(conf.middle_click_cmd));
   }
   if ( strlen( conf.right_click_cmd ) < 1 ) {
-    strcpy( conf.right_click_cmd, conf.mailclient );
+    strncpy(conf.right_click_cmd, conf.mailclient, sizeof(conf.right_click_cmd));
   }
 
   conf.nMailBoxes = popservers;
@@ -697,7 +709,7 @@ void BlitNum(int num, int x, int y)
     newx -= CHAR_WIDTH;
   } 
   
-  sprintf(buf, "%02i", num);
+  snprintf(buf, sizeof(buf), "%02i", num);
   
   BlitString(buf, newx, y);
 }
